==> libdatetime-locale-perl_1.17.orig.tar.gz: DateTime-Locale-1.17/share/agq-CM.pl <==
{
  am_pm_abbreviated => [
    "a.g",
    "a.k",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "agq-CM",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "kpa",
    "gh\N{U+0254}",
    "t\N{U+0254}m",
    "ume",
    "gh\N{U+0268}",
    "dzk",
    "nts",
  ],
  day_format_narrow => [
    "k",
    "g",
    "t",
    "u",
    "g",
    "d",
    "n",
  ],
  day_format_wide => [
    "tsu\N{U+0294}ukp\N{U+00e0}",
    "tsu\N{U+0294}ugh\N{U+0254}e",
    "tsu\N{U+0294}ut\N{U+0254}\N{U+0300}ml\N{U+00f2}",
    "tsu\N{U+0294}um\N{U+00e8}",
    "tsu\N{U+0294}ugh\N{U+0268}\N{U+0302}m",
    "tsu\N{U+0294}ndz\N{U+0268}k\N{U+0254}\N{U+0294}\N{U+0254}",
    "tsu\N{U+0294}nts\N{U+0268}",
  ],
  day_stand_alone_abbreviated => [
    "kpa",
    "gh\N{U+0254}",
    "t\N{U+0254}m",
    "ume",
    "gh\N{U+0268}",
    "dzk",
    "nts",
  ],
  day_stand_alone_narrow => [
    "k",
    "g",
    "t",
    "u",
    "g",
    "d",
    "n",
  ],
  day_stand_alone_wide => [
    "tsu\N{U+0294}ukp\N{U+00e0}",
    "tsu\N{U+0294}ugh\N{U+0254}e",
    "tsu\N{U+0294}ut\N{U+0254}\N{U+0300}ml\N{U+00f2}",
    "tsu\N{U+0294}um\N{U+00e8}",
    "tsu\N{U+0294}ugh\N{U+0268}\N{U+0302}m",
    "tsu\N{U+0294}ndz\N{U+0268}k\N{U+0254}\N{U+0294}\N{U+0254}",
    "tsu\N{U+0294}nts\N{U+0268}",
  ],
  era_abbreviated => [
    "SK",
    "BK",
  ],
  era_narrow => [
    "SK",
    "BK",
  ],
  era_wide => [
    "S\N{U+011b}e K\N{U+0268}\N{U+0300}lesto",
    "B\N{U+01ce}a K\N{U+0268}\N{U+0300}lesto",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Aghem",
  month_format_abbreviated => [
    "n\N{U+00f9}m",
    "k\N{U+0268}z",
    "t\N{U+0268}d",
    "taa",
    "see",
    "nzu",
    "dum",
    "f\N{U+0254}e",
    "dzu",
    "l\N{U+0254}m",
    "kaa",
    "fwo",
  ],
  month_format_narrow => [
    "n",
    "k",
    "t",
    "t",
    "s",
    "z",
    "k",
    "f",
    "d",
    "l",
    "c",
    "f",
  ],
  month_format_wide => [
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}n\N{U+00f9}m",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}k\N{U+0197}\N{U+0300}z\N{U+00f9}\N{U+0294}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}t\N{U+0197}\N{U+0300}d\N{U+0289}\N{U+0300}gh\N{U+00e0}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}t\N{U+01ce}af\N{U+0289}\N{U+0304}gh\N{U+0101}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+00e8}s\N{U+00e8}e",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}nz\N{U+00f9}gh\N{U+00f2}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}d\N{U+00f9}mlo",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}kw\N{U+00ee}f\N{U+0254}\N{U+0300}e",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}t\N{U+0197}\N{U+0300}f\N{U+0289}\N{U+0300}gh\N{U+00e0}dzugh\N{U+00f9}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}gh\N{U+01d4}uwel\N{U+0254}\N{U+0300}m",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}chwa\N{U+0294}\N{U+00e0}kaa wo",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+00e8}fw\N{U+00f2}o",
  ],
  month_stand_alone_abbreviated => [
    "n\N{U+00f9}m",
    "k\N{U+0268}z",
    "t\N{U+0268}d",
    "taa",
    "see",
    "nzu",
    "dum",
    "f\N{U+0254}e",
    "dzu",
    "l\N{U+0254}m",
    "kaa",
    "fwo",
  ],
  month_stand_alone_narrow => [
    "n",
    "k",
    "t",
    "t",
    "s",
    "z",
    "k",
    "f",
    "d",
    "l",
    "c",
    "f",
  ],
  month_stand_alone_wide => [
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}n\N{U+00f9}m",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}k\N{U+0197}\N{U+0300}z\N{U+00f9}\N{U+0294}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}t\N{U+0197}\N{U+0300}d\N{U+0289}\N{U+0300}gh\N{U+00e0}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}t\N{U+01ce}af\N{U+0289}\N{U+0304}gh\N{U+0101}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+00e8}s\N{U+00e8}e",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}nz\N{U+00f9}gh\N{U+00f2}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}d\N{U+00f9}mlo",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}kw\N{U+00ee}f\N{U+0254}\N{U+0300}e",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}t\N{U+0197}\N{U+0300}f\N{U+0289}\N{U+0300}gh\N{U+00e0}dzugh\N{U+00f9}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}gh\N{U+01d4}uwel\N{U+0254}\N{U+0300}m",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}chwa\N{U+0294}\N{U+00e0}kaa wo",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+00e8}fw\N{U+00f2}o",
  ],
  name => "Aghem Cameroon",
  native_language => "Aghem",
  native_name => "Aghem K\N{U+00e0}m\N{U+00e0}l\N{U+00fb}\N{U+014b}",
  native_script => undef,
  native_territory => "K\N{U+00e0}m\N{U+00e0}l\N{U+00fb}\N{U+014b}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "k\N{U+0268}b\N{U+00e2} k\N{U+0268} 1",
    "ugb\N{U+00e2} u 2",
    "ugb\N{U+00e2} u 3",
    "ugb\N{U+00e2} u 4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "k\N{U+0268}b\N{U+00e2} k\N{U+0268} 1",
    "ugb\N{U+00e2} u 2",
    "ugb\N{U+00e2} u 3",
    "ugb\N{U+00e2} u 4",
  ],
  quarter_stand_alone_abbreviated => [
    "k\N{U+0268}b\N{U+00e2} k\N{U+0268} 1",
    "ugb\N{U+00e2} u 2",
    "ugb\N{U+00e2} u 3",
    "ugb\N{U+00e2} u 4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "k\N{U+0268}b\N{U+00e2} k\N{U+0268} 1",
    "ugb\N{U+00e2} u 2",
    "ugb\N{U+00e2} u 3",
    "ugb\N{U+00e2} u 4",
  ],
  script => undef,
  territory => "Cameroon",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}

==> libdatetime-locale-perl_1.37.orig.tar.gz: DateTime-Locale-1.37/share/agq-CM.pl <==
{
  am_pm_abbreviated => [
    "a.g",
    "a.k",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "agq-CM",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "kpa",
    "gh\N{U+0254}",
    "t\N{U+0254}m",
    "ume",
    "gh\N{U+0268}",
    "dzk",
    "nts",
  ],
  day_format_narrow => [
    "k",
    "g",
    "t",
    "u",
    "g",
    "d",
    "n",
  ],
  day_format_wide => [
    "tsu\N{U+0294}ukp\N{U+00e0}",
    "tsu\N{U+0294}ugh\N{U+0254}e",
    "tsu\N{U+0294}ut\N{U+0254}\N{U+0300}ml\N{U+00f2}",
    "tsu\N{U+0294}um\N{U+00e8}",
    "tsu\N{U+0294}ugh\N{U+0268}\N{U+0302}m",
    "tsu\N{U+0294}ndz\N{U+0268}k\N{U+0254}\N{U+0294}\N{U+0254}",
    "tsu\N{U+0294}nts\N{U+0268}",
  ],
  day_stand_alone_abbreviated => [
    "kpa",
    "gh\N{U+0254}",
    "t\N{U+0254}m",
    "ume",
    "gh\N{U+0268}",
    "dzk",
    "nts",
  ],
  day_stand_alone_narrow => [
    "k",
    "g",
    "t",
    "u",
    "g",
    "d",
    "n",
  ],
  day_stand_alone_wide => [
    "tsu\N{U+0294}ukp\N{U+00e0}",
    "tsu\N{U+0294}ugh\N{U+0254}e",
    "tsu\N{U+0294}ut\N{U+0254}\N{U+0300}ml\N{U+00f2}",
    "tsu\N{U+0294}um\N{U+00e8}",
    "tsu\N{U+0294}ugh\N{U+0268}\N{U+0302}m",
    "tsu\N{U+0294}ndz\N{U+0268}k\N{U+0254}\N{U+0294}\N{U+0254}",
    "tsu\N{U+0294}nts\N{U+0268}",
  ],
  era_abbreviated => [
    "SK",
    "BK",
  ],
  era_narrow => [
    "SK",
    "BK",
  ],
  era_wide => [
    "S\N{U+011b}e K\N{U+0268}\N{U+0300}lesto",
    "B\N{U+01ce}a K\N{U+0268}\N{U+0300}lesto",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Aghem",
  month_format_abbreviated => [
    "n\N{U+00f9}m",
    "k\N{U+0268}z",
    "t\N{U+0268}d",
    "taa",
    "see",
    "nzu",
    "dum",
    "f\N{U+0254}e",
    "dzu",
    "l\N{U+0254}m",
    "kaa",
    "fwo",
  ],
  month_format_narrow => [
    "n",
    "k",
    "t",
    "t",
    "s",
    "z",
    "k",
    "f",
    "d",
    "l",
    "c",
    "f",
  ],
  month_format_wide => [
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}n\N{U+00f9}m",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}k\N{U+0197}\N{U+0300}z\N{U+00f9}\N{U+0294}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}t\N{U+0197}\N{U+0300}d\N{U+0289}\N{U+0300}gh\N{U+00e0}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}t\N{U+01ce}af\N{U+0289}\N{U+0304}gh\N{U+0101}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+00e8}s\N{U+00e8}e",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}nz\N{U+00f9}gh\N{U+00f2}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}d\N{U+00f9}mlo",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}kw\N{U+00ee}f\N{U+0254}\N{U+0300}e",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}t\N{U+0197}\N{U+0300}f\N{U+0289}\N{U+0300}gh\N{U+00e0}dzugh\N{U+00f9}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}gh\N{U+01d4}uwel\N{U+0254}\N{U+0300}m",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}chwa\N{U+0294}\N{U+00e0}kaa wo",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+00e8}fw\N{U+00f2}o",
  ],
  month_stand_alone_abbreviated => [
    "n\N{U+00f9}m",
    "k\N{U+0268}z",
    "t\N{U+0268}d",
    "taa",
    "see",
    "nzu",
    "dum",
    "f\N{U+0254}e",
    "dzu",
    "l\N{U+0254}m",
    "kaa",
    "fwo",
  ],
  month_stand_alone_narrow => [
    "n",
    "k",
    "t",
    "t",
    "s",
    "z",
    "k",
    "f",
    "d",
    "l",
    "c",
    "f",
  ],
  month_stand_alone_wide => [
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}n\N{U+00f9}m",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}k\N{U+0197}\N{U+0300}z\N{U+00f9}\N{U+0294}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}t\N{U+0197}\N{U+0300}d\N{U+0289}\N{U+0300}gh\N{U+00e0}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}t\N{U+01ce}af\N{U+0289}\N{U+0304}gh\N{U+0101}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+00e8}s\N{U+00e8}e",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}nz\N{U+00f9}gh\N{U+00f2}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}d\N{U+00f9}mlo",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}kw\N{U+00ee}f\N{U+0254}\N{U+0300}e",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}t\N{U+0197}\N{U+0300}f\N{U+0289}\N{U+0300}gh\N{U+00e0}dzugh\N{U+00f9}",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}gh\N{U+01d4}uwel\N{U+0254}\N{U+0300}m",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+0254}\N{U+0300}chwa\N{U+0294}\N{U+00e0}kaa wo",
    "ndz\N{U+0254}\N{U+0300}\N{U+014b}\N{U+00e8}fw\N{U+00f2}o",
  ],
  name => "Aghem Cameroon",
  native_language => "Aghem",
  native_name => "Aghem K\N{U+00e0}m\N{U+00e0}l\N{U+00fb}\N{U+014b}",
  native_script => undef,
  native_territory => "K\N{U+00e0}m\N{U+00e0}l\N{U+00fb}\N{U+014b}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "k\N{U+0268}b\N{U+00e2} k\N{U+0268} 1",
    "ugb\N{U+00e2} u 2",
    "ugb\N{U+00e2} u 3",
    "ugb\N{U+00e2} u 4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "k\N{U+0268}b\N{U+00e2} k\N{U+0268} 1",
    "ugb\N{U+00e2} u 2",
    "ugb\N{U+00e2} u 3",
    "ugb\N{U+00e2} u 4",
  ],
  quarter_stand_alone_abbreviated => [
    "k\N{U+0268}b\N{U+00e2} k\N{U+0268} 1",
    "ugb\N{U+00e2} u 2",
    "ugb\N{U+00e2} u 3",
    "ugb\N{U+00e2} u 4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "k\N{U+0268}b\N{U+00e2} k\N{U+0268} 1",
    "ugb\N{U+00e2} u 2",
    "ugb\N{U+00e2} u 3",
    "ugb\N{U+00e2} u 4",
  ],
  script => undef,
  territory => "Cameroon",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
